"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const util_1 = require("util");
const path_1 = __importDefault(require("path"));
const _1 = require(".");
const dot_object_1 = __importDefault(require("dot-object"));
const fsReadFile = util_1.promisify(fs_1.readFile);
const fsWriteFile = util_1.promisify(fs_1.writeFile);
const CONFIG_FILE = () => path_1.default.resolve(process.env.CLI_CWD || './', '.origami');
var config;
(function (config_1) {
    /**
     * Converts origami_x_y envrionment variables to an object
     * @returns {Object} Object of origami environment variables
    */
    config_1.env = (obj = {}) => {
        const e = Object.entries(process.env)
            .filter(([key, value]) => /^origami_.*$/.test(key))
            .map(([key, value]) => [
            key
                // Replace _ with .
                .replace(/_/g, '.')
                // Remove preceding 'origami.'
                .split('.').slice(1).join('.'),
            value
        ])
            .forEach(([key, value]) => {
            dot_object_1.default.str(key, value, obj);
        });
        return obj;
    };
    /**
     * Attempt to load the .origami file at the current directory. Overwrites with any ENV variables
     * @returns {Origami.Config|Boolean} The Origami file as json, or false if it cannot be
     * found or loaded correctly
    */
    config_1.read = async () => {
        let c = {};
        try {
            c = JSON.parse((await fsReadFile(CONFIG_FILE())).toString());
        }
        catch (e) {
            return false;
        }
        c = config_1.env(c);
        return c;
    };
    /**
     * Override/write the .origami file
     * @param file JSON config for Origami app to override
     */
    config_1.write = async (file) => {
        const TAB_SIZE = 4;
        return fsWriteFile(CONFIG_FILE(), JSON.stringify(file, null, TAB_SIZE));
    };
    config_1.validate = (config) => {
        try {
            _1.requireKeys([
                'store'
            ], config);
        }
        catch (e) {
            return _1.error(new Error(`Origami: Missing '${e.key}' setting`));
        }
        // ------------------------------------------------------ Validate store
        // const store = `origami-store-${config.store.type}`;
        // try {
        //     require(path.resolve(process.cwd(), 'node_modules', store, 'package.json'));
        // } catch (e) {
        //     if (e.name === 'Error') {
        //         console.log(path.resolve(process.cwd(), 'node_modules', store, 'package.json'));
        //         return error(
        //                 new Error(
        //                     `Origami: Could not find store plugin '${store}'. Try running 'yarn install ${store}'`
        //                 )
        //             );
        //     }
        //     return error(e);
        // }
    };
})(config = exports.config || (exports.config = {}));
